Processor.App.Extractor.extractor.BaseExtractor.\_\_init\_\_
============================================================

.. currentmodule:: Processor.App.Extractor.extractor

.. automethod:: BaseExtractor.__init__